@@ -1,12 +1,16 @@
 /* Everything */
 
+/* Qt Edition */
+#ifndef QT_EDITION
+#  define QT_EDITION QT_EDITION_OPENSOURCE
+#endif
+
 #define QT_BUILD_KEY "amd64 OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
-
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_POINTER_SIZE 8
@@ -23,16 +27,28 @@
 # define QT_NO_EXCEPTIONS
 #endif
 
-#if defined(QT_NO_IMAGEIO_JPEG) && defined(QT_IMAGEIO_JPEG)
-# undef QT_NO_IMAGEIO_JPEG
-#elif !defined(QT_NO_IMAGEIO_JPEG) && !defined(QT_IMAGEIO_JPEG)
-# define QT_NO_IMAGEIO_JPEG
+#if defined(QT_NO_IMAGEFORMAT_JPEG) && defined(QT_IMAGEFORMAT_JPEG)
+# undef QT_NO_IMAGEFORMAT_JPEG
+#elif !defined(QT_NO_IMAGEFORMAT_JPEG) && !defined(QT_IMAGEFORMAT_JPEG)
+# define QT_NO_IMAGEFORMAT_JPEG
 #endif
 
-#if defined(QT_NO_NIS) && defined(QT_NIS)
-# undef QT_NO_NIS
-#elif !defined(QT_NO_NIS) && !defined(QT_NIS)
-# define QT_NO_NIS
+#if defined(QT_NO_IMAGEFORMAT_MNG) && defined(QT_IMAGEFORMAT_MNG)
+# undef QT_NO_IMAGEFORMAT_MNG
+#elif !defined(QT_NO_IMAGEFORMAT_MNG) && !defined(QT_IMAGEFORMAT_MNG)
+# define QT_NO_IMAGEFORMAT_MNG
+#endif
+
+#if defined(QT_NO_NAS) && defined(QT_NAS)
+# undef QT_NO_NAS
+#elif !defined(QT_NO_NAS) && !defined(QT_NAS)
+# define QT_NO_NAS
+#endif
+
+#if defined(QT_NO_SXV) && defined(QT_SXV)
+# undef QT_NO_SXV
+#elif !defined(QT_NO_SXV) && !defined(QT_SXV)
+# define QT_NO_SXV
 #endif
 
 #if defined(QT_NO_ZLIB) && defined(QT_ZLIB)
